==> wpilib-2017.0.1.tar.gz: wpilib-2017.0.1/wpilib/interfaces/joystickbase.py <==
# validated: 2016-12-01 AA 140c365e4b99 shared/java/edu/wpi/first/wpilibj/JoystickBase.java
# ----------------------------------------------------------------------------
# Copyright (c) FIRST 2016. All Rights Reserved.
# Open Source Software - may be modified and shared by FRC teams. The code
# must be accompanied by the FIRST BSD license file in the root directory of
# the project.
#----------------------------------------------------------------------------

from .generichid import GenericHID

__all__ = ["JoystickBase"]

class JoystickBase(GenericHID):
    """
    JoystickBase Interface.
    """

    def __init__(self, port):
        super().__init__(port)

    def getZ(self, hand=None):
        """Get the z position of the HID.

        :param hand: which hand, left or right
        :returns: the z position
        """

        raise NotImplementedError

    def getTwist(self):
        """Get the twist value.

        :returns: the twist value
        """

        raise NotImplementedError

    def getThrottle(self):
        """Get the throttle.

        :returns: the throttle value
        """

        raise NotImplementedError

    def getTrigger(self, hand=None):
        """Is the trigger pressed.

        :param hand: which hand
        :returns: true if the trigger for the given hand is pressed
        """

        raise NotImplementedError

    def getTop(self, hand=None):
        """Is the top button pressed.

        :param hand: which hand
        :returns: true if hte top button for the given hand is pressed
        """

        raise NotImplementedError

    def getPOV(self, pov=0):
        raise NotImplementedError

    def getPOVCount(self):
        raise NotImplementedError

    def getType(self):
        raise NotImplementedError

    def getName(self):
        raise NotImplementedError

    def setOutput(self, outputNumber, value):
        raise NotImplementedError

    def setOutputs(self, value):
        raise NotImplementedError

    def setRumble(self, type, value):
        raise NotImplementedError

==> wpilib-2019.2.3.tar.gz: wpilib-2019.2.3/wpilib/interfaces/joystickbase.py <==
# validated: 2017-11-13 TW 21585f70a88e edu/wpi/first/wpilibj/JoystickBase.java
# ----------------------------------------------------------------------------
# Copyright (c) FIRST 2016. All Rights Reserved.
# Open Source Software - may be modified and shared by FRC teams. The code
# must be accompanied by the FIRST BSD license file in the root directory of
# the project.
# ----------------------------------------------------------------------------
import warnings
from typing import Optional

from .generichid import GenericHID

__all__ = ["JoystickBase"]


class JoystickBase(GenericHID):
    """
    JoystickBase Interface.

    ..deprecated:: 2018.0.0
        Inherit directly from GenericHID instead.
    """

    def __init__(self, port: int) -> None:
        warnings.warn(
            "JoystickBase is deprecated. Inherit directly from GenericHID instead",
            DeprecationWarning,
            stacklevel=2,
        )
        super().__init__(port)

    def getZ(self, hand: Optional[GenericHID.Hand] = None) -> float:
        """Get the z position of the HID.

        :param hand: which hand, left or right
        :returns: the z position
        """

        raise NotImplementedError

    def getTwist(self) -> float:
        """Get the twist value.

        :returns: the twist value
        """

        raise NotImplementedError

    def getThrottle(self) -> float:
        """Get the throttle.

        :returns: the throttle value
        """

        raise NotImplementedError
